package com.anji.xwl.pojo;

import com.wb.util.StringUtil;


/**
 * Created by Guo on 2016/7/7.
 * 查询代码使用
 */
public class Code {
    private String fldId;
    private String fldNam;
    private String sysCod;
    private String cName;
    private String eName;
    private String comNam1;
	private String comNam2;
    private String tentantId;
    private String parId;
    
    public String getComNam1() {
		return comNam1;
	}
	public void setComNam1(String comNam1) {
		this.comNam1 = comNam1;
	}
	public String getComNam2() {
		return comNam2;
	}
	public void setComNam2(String comNam2) {
		this.comNam2 = comNam2;
	}

    public void setFldId(String fldId) {
        this.fldId = fldId;
    }
    public void setFldNam(String fldNam) {
        this.fldNam = fldNam;
    }
    public void setSysCod(String sysCod) {
        this.sysCod = sysCod;
    }
    public void setcName(String cName) {
        this.cName = cName;
    }
    public void seteName(String eName) {
        this.eName = eName;
    }
    public void setTentantId(String tentantId) {
        this.tentantId = tentantId;
    }
    public String getFldId() {
        return fldId;
    }
    public String getFldNam() {
        return fldNam;
    }
    public String getSysCod() {
        return sysCod;
    }
    public String getcName() {
        return cName;
    }
    public String geteName() {
        return eName;
    }
    public String getTentantId() {
        if(StringUtil.isEmpty(tentantId))
            return "@@@";
        else
            return tentantId;
    }
    public String getParId() {
        if(StringUtil.isEmpty(parId))
            return "@@@";
        else
        return parId;
    }
    public void setParId(String parId) {
        this.parId = parId;
    }

}
